@@ -118,7 +118,7 @@ def ddr_error_msg(message):
     """
     print("%%%% DDR Error: " + str(message))
 
-def ddr_ddr_write_to_file(data: str, target_dir: str, filename: str, mode: str = "w"):
+def ddr_write_to_file(data: str, target_dir: str, filename: str, mode: str = "w"):
     """
         This function writes an informration to the DDR execution log
         
@@ -208,10 +208,10 @@ def ddr_get_truth(data, relate, value, debug_flag):
     '''
     if isinstance(data, str):
        result = relate(str(data), str(value))
-       debug_msg(debug_flag, f"ddr_get_truth: data_read: {str(data)} operator: {str(relate)} value: {str(value)} result: {str(result)}")
+       ddr_debug_msg(debug_flag, f"ddr_get_truth: data_read: {str(data)} operator: {str(relate)} value: {str(value)} result: {str(result)}")
     else:   
         result = relate(int(data), int(value))
-        debug_msg(debug_flag, f"ddr_get_truth: data_read: {str(data)} operator: {str(relate)} value: {str(value)} result: {str(result)}")
+        ddr_debug_msg(debug_flag, f"ddr_get_truth: data_read: {str(data)} operator: {str(relate)} value: {str(value)} result: {str(result)}")
     return result
 
 def ddr_nc_notify(device, access_type, triggers, return_response, debug_flag=False):
@@ -257,7 +257,7 @@ def ddr_nc_notify(device, access_type, triggers, return_response, debug_flag=Fal
 
     except Exception as e:
       notify_conn.close_session()
-      error_msg(f"ddr_nc_notify connect Exception: {str(access_type)} {str(e)}")
+      ddr_error_msg(f"ddr_nc_notify connect Exception: {str(access_type)} {str(e)}")
       raise
 
     notify_conn.async_mode = False
@@ -277,11 +277,11 @@ def ddr_nc_notify(device, access_type, triggers, return_response, debug_flag=Fal
        notification_found = False
        notif = notify_conn.take_notification(block=True) # block on IO waiting for the NETCONF notification
        notify_xml = notif.notification_xml
-       debug_msg(debug_flag, f"ddr_nc_notify: RFC5277 notification received: \n {str(notify_xml)}")
+       ddr_debug_msg(debug_flag, f"ddr_nc_notify: RFC5277 notification received: \n {str(notify_xml)}")
          
       except Exception as e:
         notify_conn.close_session()
-        error_msg(f"ddr_nc_notify connect Exception: {str(access_type)} {str(e)}")
+        ddr_error_msg(f"ddr_nc_notify connect Exception: {str(access_type)} {str(e)}")
         raise
         break
         return None
@@ -289,7 +289,7 @@ def ddr_nc_notify(device, access_type, triggers, return_response, debug_flag=Fal
       notify_conn.close_session()
       
       if all([val in str(notify_xml) for val in triggers]): 
-        debug_msg(debug_flag, f"ddr_nc_notify: trigger conditions found: \n {str(notify_xml)}")
+        ddr_debug_msg(debug_flag, f"ddr_nc_notify: trigger conditions found: \n {str(notify_xml)}")
            
         if return_response:
             return str(notify_xml)
@@ -348,7 +348,7 @@ def ddr_show_trigger(device, access_type, genie_parser_name, show_template, pcou
         #
         # Loop for a maximum of retries times to test value
         #
-          debug_msg(debug_flag, f"ddr_show_trigger: command: " + str(command))
+          ddr_debug_msg(debug_flag, f"ddr_show_trigger: command: " + str(command))
 
           condition_met = False
           test_count = 1
@@ -361,7 +361,7 @@ def ddr_show_trigger(device, access_type, genie_parser_name, show_template, pcou
         #
             if str(access_type) == 'cli':
               response = cli.cli(command)
-              debug_msg(debug_flag, f" ddr_show_trigger: cli python response: {str(response)}")
+              ddr_debug_msg(debug_flag, f" ddr_show_trigger: cli python response: {str(response)}")
 
             else:
         #
@@ -370,7 +370,7 @@ def ddr_show_trigger(device, access_type, genie_parser_name, show_template, pcou
               try:
                 options = '-q -oStrictHostKeyChecking=no -oUserKnownHostsFile=/dev/null -oPubkeyAuthentication=no'
                 ssh_cmd = 'ssh %s@%s %s "%s"' % (device[2], device[0], options, command)
-                debug_msg(debug_flag, f"ddr_show_trigger: ssh_cmd: {str(ssh_cmd)}")
+                ddr_debug_msg(debug_flag, f"ddr_show_trigger: ssh_cmd: {str(ssh_cmd)}")
 
                 child = pexpect.spawn(ssh_cmd, timeout= 20, encoding='utf-8')
                 child.delaybeforesend = None
@@ -378,10 +378,10 @@ def ddr_show_trigger(device, access_type, genie_parser_name, show_template, pcou
                 child.sendline(device[3])
                 child.expect(pexpect.EOF) #result contains the ping result
                 response = child.before
-                debug_msg(debug_flag, f"ddr_show_trigger: ssh response: {str(response)}")
+                ddr_debug_msg(debug_flag, f"ddr_show_trigger: ssh response: {str(response)}")
 
               except Exception as e:
-                error_msg(f"ddr_show_trigger Exception: {str(e)}")
+                ddr_error_msg(f"ddr_show_trigger Exception: {str(e)}")
                 child.close()
                 raise
     #
@@ -389,7 +389,7 @@ def ddr_show_trigger(device, access_type, genie_parser_name, show_template, pcou
     #
             parser = genie_str_to_class(genie_parser_name)
             dictionary = parser.parse(output=response)
-            debug_msg(debug_flag, f"ddr_show_trigger: parser dictionary: {str(dictionary)}")
+            ddr_debug_msg(debug_flag, f"ddr_show_trigger: parser dictionary: {str(dictionary)}")
             parameter_value = dictionary[str(parameter)]
     #
     # Test to see if condition to trigger is satisfied
@@ -397,10 +397,10 @@ def ddr_show_trigger(device, access_type, genie_parser_name, show_template, pcou
             if ddr_get_truth(parameter_value, relate, test_value, debug_flag):
               condition_met = True
             if condition_met == True:
-              info_msg("ddr_show_trigger trigger conditions satisfied")
+              ddr_info_msg("ddr_show_trigger trigger conditions satisfied")
               return dictionary
             else:
-              debug_msg(debug_flag, f"ddr_show_trigger: wait seconds and test again: {str(interval)}")
+              ddr_debug_msg(debug_flag, f"ddr_show_trigger: wait seconds and test again: {str(interval)}")
             time.sleep(interval)
     #
     # If event does not occur during number of interations return None
@@ -408,7 +408,7 @@ def ddr_show_trigger(device, access_type, genie_parser_name, show_template, pcou
           return "show trigger did not occur in expected time"
 
         except Exception as e:
-          error_msg(f"ddr_show_trigger Exception: {str(e)}")
+          ddr_error_msg(f"ddr_show_trigger Exception: {str(e)}")
           raise
 
 def ddr_nc_get_trigger(device, access_type, xpath, pcount, par1, par2, par3, leafs, relate, test_value, interval, retries, debug_flag=False):
@@ -451,7 +451,7 @@ def ddr_nc_get_trigger(device, access_type, xpath, pcount, par1, par2, par3, lea
           command = str(xpath).format(str(par1), str(par2))
         elif int(pcount) == 3:
           command = str(xpath).format(str(par1), str(par2), str(par3))
-      debug_msg(debug_flag, f"DDR ddr_nc_get xpath: {str(command)}")
+      ddr_debug_msg(debug_flag, f"DDR ddr_nc_get xpath: {str(command)}")
 
     #
     # Test for the parameter value retries times waiting interval seconds between tries
@@ -464,19 +464,19 @@ def ddr_nc_get_trigger(device, access_type, xpath, pcount, par1, par2, par3, lea
           test_count = 1 # Loop until condition found or script terminated
 
         get_value = ddr_nc_get(device, access_type, command, leafs, True, debug_flag)
-        debug_msg(debug_flag, f"ddr_nc_get_trigger get_values: {str(get_value)}")
+        ddr_debug_msg(debug_flag, f"ddr_nc_get_trigger get_values: {str(get_value)}")
         if get_value == None:
-          debug_msg(debug_flag, f"ddr_nc_get_trigger: No data found or timeout")
+          ddr_debug_msg(debug_flag, f"ddr_nc_get_trigger: No data found or timeout")
         else:
-          debug_msg(debug_flag, f"ddr_nc_get_trigger: data read: {str(get_value)}")
+          ddr_debug_msg(debug_flag, f"ddr_nc_get_trigger: data read: {str(get_value)}")
           if ddr_get_truth(get_value, relate, test_value, debug_flag):
               condition_met = True
               return get_value
           if condition_met == True:
-            debug_msg(debug_flag, "ddr_nc_get_trigger: trigger event detected")
+            ddr_debug_msg(debug_flag, "ddr_nc_get_trigger: trigger event detected")
             return get_value
           else:
-            debug_msg(debug_flag, f"ddr_nc_get_trigger: wait seconds and test again: {str(interval)}")
+            ddr_debug_msg(debug_flag, f"ddr_nc_get_trigger: wait seconds and test again: {str(interval)}")
             time.sleep(interval)
     #
     # if the trigger condition does not occur, return "none"
@@ -484,7 +484,7 @@ def ddr_nc_get_trigger(device, access_type, xpath, pcount, par1, par2, par3, lea
       return "none"
 
     except Exception as e:
-      error_msg(f"ddr_nc_get_trigger Exception: {str(e)}")
+      ddr_error_msg(f"ddr_nc_get_trigger Exception: {str(e)}")
       raise
 
 def ddr_nc_get(device, access_type, xpath, leaf, return_response, debug_flag=False):
@@ -542,7 +542,7 @@ def ddr_nc_get(device, access_type, xpath, leaf, return_response, debug_flag=Fal
     #
       get_result = netconf_connection.get(filter=('subtree', str(xpath)))
       netconf_connection.close_session()
-      debug_msg(debug_flag, f"ddr_nc_get get_result: {str(get_result)}")
+      ddr_debug_msg(debug_flag, f"ddr_nc_get get_result: {str(get_result)}")
     #
     # If leaf is set to 'all', return the complete NETCONF response
     #
@@ -550,7 +550,7 @@ def ddr_nc_get(device, access_type, xpath, leaf, return_response, debug_flag=Fal
         return get_result
         
       nodes = xml.dom.minidom.parseString(get_result.xml).getElementsByTagName(leaf)
-      debug_msg(debug_flag, f"ddr_nc_get nodes: {str(nodes)}")
+      ddr_debug_msg(debug_flag, f"ddr_nc_get nodes: {str(nodes)}")
     #
     # get all values for objects containing the leaf
     #
@@ -558,7 +558,7 @@ def ddr_nc_get(device, access_type, xpath, leaf, return_response, debug_flag=Fal
         return "No matching data found"
       for node in nodes:
         value = node.firstChild.nodeValue
-      debug_msg(debug_flag, f"ddr_nc_get value: {str(value)}")
+      ddr_debug_msg(debug_flag, f"ddr_nc_get value: {str(value)}")
                 
       if return_response:
         return value
@@ -567,7 +567,7 @@ def ddr_nc_get(device, access_type, xpath, leaf, return_response, debug_flag=Fal
 
     except Exception as e:
       netconf_connection.close_session()
-      error_msg(f"ddr_nc_get Exception: {str(e)}")
+      ddr_error_msg(f"ddr_nc_get Exception: {str(e)}")
       raise
 
 def ddr_nc_get_config(device, access_type, xpath, leaf, return_response, debug_flag=False):
@@ -624,7 +624,7 @@ def ddr_nc_get_config(device, access_type, xpath, leaf, return_response, debug_f
     #
       get_result = netconf_connection.get_config('running', filter=('subtree', str(xpath)))
       netconf_connection.close_session()
-      debug_msg(debug_flag, f"ddr_nc_get_config result: {str(get_result)}")
+      ddr_debug_msg(debug_flag, f"ddr_nc_get_config result: {str(get_result)}")
     #
     # if all leafs are requested return the complete RPC response
     # otherwise only return the leaf specified in the call
@@ -637,7 +637,7 @@ def ddr_nc_get_config(device, access_type, xpath, leaf, return_response, debug_f
       
       else:
         nodes = xml.dom.minidom.parseString(get_result.xml).getElementsByTagName(leaf)
-        debug_msg(debug_flag, f"ddr_nc_get_config nodes: {str(nodes)}")
+        ddr_debug_msg(debug_flag, f"ddr_nc_get_config nodes: {str(nodes)}")
     #
     # get all values for objects containing the leaf
     #
@@ -645,7 +645,7 @@ def ddr_nc_get_config(device, access_type, xpath, leaf, return_response, debug_f
           return "No matching data found"
         for node in nodes:
           value = node.firstChild.nodeValue
-        debug_msg(debug_flag, f"ddr_nc_get_config value: {str(value)}")
+        ddr_debug_msg(debug_flag, f"ddr_nc_get_config value: {str(value)}")
                 
         if return_response:
           return value
@@ -654,7 +654,7 @@ def ddr_nc_get_config(device, access_type, xpath, leaf, return_response, debug_f
           
     except Exception as e:
       netconf_connection.close_session()
-      error_msg(f"ddr_nc_get Exception: {str(e)}")
+      ddr_error_msg(f"ddr_nc_get Exception: {str(e)}")
       raise
 
 def ddr_nc_edit_config(device, access_type, datastore, commit, xpath, return_response, debug_flag=False):
@@ -711,10 +711,10 @@ def ddr_nc_edit_config(device, access_type, datastore, commit, xpath, return_res
 #          netconf_connection.edit_config(config=xpath, target=datastore)
 #          result = netconf_connection.commit(confirmed=True)
 #      netconf_connection.unlock(target=datastore)
-      debug_msg(debug_flag, f"ddr_nc_edit_config xpath: {str(xpath)} datastore: {str(datastore)}")
+      ddr_debug_msg(debug_flag, f"ddr_nc_edit_config xpath: {str(xpath)} datastore: {str(datastore)}")
       result = netconf_connection.edit_config(config=str(xpath), target=datastore)
       netconf_connection.close_session()            
-      debug_msg(debug_flag, " ddr_nc_edit_config result: " + str(result))
+      ddr_debug_msg(debug_flag, " ddr_nc_edit_config result: " + str(result))
 
       if return_response:
         return result
@@ -761,15 +761,15 @@ def ddr_nc_get_parameter(device, access_type, xpath, pcount, par1, par2, par3, l
           command = str(xpath).format(str(par1), str(par2))
         elif int(pcount) == 3:
           command = str(xpath).format(str(par1), str(par2), str(par3))
-      debug_msg(debug_flag, "ddr_nc_get_parameter xpath: " + str(command))
+      ddr_debug_msg(debug_flag, "ddr_nc_get_parameter xpath: " + str(command))
 
       get_value = ddr_nc_get(device, access_type, command, leafs, True, debug_flag)
-      debug_msg(debug_flag, f"ddr_nc_get_parameter get_values: {str(get_value)}")
+      ddr_debug_msg(debug_flag, f"ddr_nc_get_parameter get_values: {str(get_value)}")
 
       if get_value == None:
-        debug_msg(debug_flag, "ddr_nc_get_parameter: No data found or timeout")
+        ddr_debug_msg(debug_flag, "ddr_nc_get_parameter: No data found or timeout")
       else:
-        debug_msg(debug_flag, f"ddr_nc_get_parameter: data read: {str(get_value)}")
+        ddr_debug_msg(debug_flag, f"ddr_nc_get_parameter: data read: {str(get_value)}")
 
       if return_value:
         return get_value
@@ -777,7 +777,7 @@ def ddr_nc_get_parameter(device, access_type, xpath, pcount, par1, par2, par3, l
         return None
 
     except Exception as e:
-      error_msg(f"ddr_nc_get_parameter Exception: {str(e)}")
+      ddr_error_msg(f"ddr_nc_get_parameter Exception: {str(e)}")
       raise
 
 def ddr_nc_get_config_parameter(device, access_type, xpath, pcount, par1, par2, par3, leafs, return_value, debug_flag=False):
@@ -816,14 +816,14 @@ def ddr_nc_get_config_parameter(device, access_type, xpath, pcount, par1, par2,
           command = str(xpath).format(str(par1), str(par2))
         elif int(pcount) == 3:
           command = str(xpath).format(str(par1), str(par2), str(par3))
-      debug_msg(debug_flag, f"ddr_nc_get_config_parameter xpath: {str(command)}")
+      ddr_debug_msg(debug_flag, f"ddr_nc_get_config_parameter xpath: {str(command)}")
 
       get_value = ddr_nc_get_config(device, access_type, command, leafs, True)
-      debug_msg(debug_flag, f"ddr_nc_get_config_parameter get_values: {str(get_value)}")
+      ddr_debug_msg(debug_flag, f"ddr_nc_get_config_parameter get_values: {str(get_value)}")
       if get_value == None:
-        debug_msg(debug_flag, "ddr_nc_get_config_parameter: No data found or timeout")
+        ddr_debug_msg(debug_flag, "ddr_nc_get_config_parameter: No data found or timeout")
       else:
-        debug_msg(debug_flag, f"ddr_nc_get_config_parameter: data read: {str(get_value)}")
+        ddr_debug_msg(debug_flag, f"ddr_nc_get_config_parameter: data read: {str(get_value)}")
 
       if return_value:
         return get_value
@@ -831,7 +831,7 @@ def ddr_nc_get_config_parameter(device, access_type, xpath, pcount, par1, par2,
         return None
 
     except Exception as e:
-      error_msg(f"ddr_nc_get_config_parameter Exception: {str(e)}")
+      ddr_error_msg(f"ddr_nc_get_config_parameter Exception: {str(e)}")
       raise
 
 def ddr_write_to_syslog(syslog_message, debug_flag=False):
@@ -852,7 +852,7 @@ def ddr_write_to_syslog(syslog_message, debug_flag=False):
         numbytes = os.write(tty_fd, str.encode(syslog_message + "\n"))
         os.close(tty_fd)
     except Exception as e:
-      error_msg(f"Writing Syslog notification Exception: {syslog_message} \n {str(e)}")
+      ddr_error_msg(f"Writing Syslog notification Exception: {syslog_message} \n {str(e)}")
       raise
 
 def ddr_wait(seconds, debug_flag=False):
@@ -893,10 +893,10 @@ def ddr_cli_command(device, access_type, command, return_response, timestamp, de
       if str(access_type) == 'cli':
           if return_response:
               response = cli.cli(cli_command)
-              debug_msg(debug_flag, f"ddr_cli_command: {str(cli_command)} response: {str(response)}")
+              ddr_debug_msg(debug_flag, f"ddr_cli_command: {str(cli_command)} response: {str(response)}")
           else:
               response = cli.clip(cli_command)
-              debug_msg(debug_flag, f"ddr_cli_command: {str(cli_command)} response: {str(response)}")
+              ddr_debug_msg(debug_flag, f"ddr_cli_command: {str(cli_command)} response: {str(response)}")
       else:
     #
     # Use SSH to run the show command
@@ -904,7 +904,7 @@ def ddr_cli_command(device, access_type, command, return_response, timestamp, de
         try:
           options = '-q -oStrictHostKeyChecking=no -oUserKnownHostsFile=/dev/null -oPubkeyAuthentication=no'
           ssh_cmd = 'ssh %s@%s %s "%s"' % (device[2], device[0], options, cli_command)
-          debug_msg(debug_flag, f"ddr_cli_command: ssh_cmd: {str(ssh_cmd)}")
+          ddr_debug_msg(debug_flag, f"ddr_cli_command: ssh_cmd: {str(ssh_cmd)}")
 
           child = pexpect.spawn(ssh_cmd, timeout= 20, encoding='utf-8')
           child.delaybeforesend = None
@@ -913,7 +913,7 @@ def ddr_cli_command(device, access_type, command, return_response, timestamp, de
           child.sendline(device[3])
           child.expect(pexpect.EOF)
           response = child.before
-          debug_msg(debug_flag, f"ddr_cli_command: response: {str(response)}")
+          ddr_debug_msg(debug_flag, f"ddr_cli_command: response: {str(response)}")
 
         except Exception as e:
           child.close()
@@ -924,7 +924,7 @@ def ddr_cli_command(device, access_type, command, return_response, timestamp, de
       else:
         return None
     except Exception as e:
-      error_msg(f"ddr_cli_command Exception: {str(e)} : {str(cli_command)}")
+      ddr_error_msg(f"ddr_cli_command Exception: {str(e)} : {str(cli_command)}")
       raise
 
 def ddr_cli_configure(device, access_type, command, return_response, timestamp, debug_flag=False):
@@ -955,10 +955,10 @@ def ddr_cli_configure(device, access_type, command, return_response, timestamp,
       if str(access_type) == 'cli':
           if return_response:
               response = cli.configure(cli_command)
-              debug_msg(debug_flag, f"ddr_cli_configure: {str(cli_command)} response: {str(response)}")
+              ddr_debug_msg(debug_flag, f"ddr_cli_configure: {str(cli_command)} response: {str(response)}")
           else:
               response = cli.clip(cli_command)
-              debug_msg(debug_flag, f"ddr_cli_configure: {str(cli_command)} response: {str(response)}")
+              ddr_debug_msg(debug_flag, f"ddr_cli_configure: {str(cli_command)} response: {str(response)}")
       else:
     #
     # Use SSH to run the configuration command
@@ -966,7 +966,7 @@ def ddr_cli_configure(device, access_type, command, return_response, timestamp,
         try:
           options = '-q -oStrictHostKeyChecking=no -oUserKnownHostsFile=/dev/null -oPubkeyAuthentication=no'
           ssh_cmd = 'ssh %s@%s %s "%s"' % (device[2], device[0], options, cli_command)
-          debug_msg(debug_flag, f"ddr_cli_configure: ssh_cmd: {str(ssh_cmd)}")
+          ddr_debug_msg(debug_flag, f"ddr_cli_configure: ssh_cmd: {str(ssh_cmd)}")
 
           child = pexpect.spawn(ssh_cmd, timeout= 20, encoding='utf-8')
           child.delaybeforesend = None
@@ -975,7 +975,7 @@ def ddr_cli_configure(device, access_type, command, return_response, timestamp,
           child.sendline(device[3])
           child.expect(pexpect.EOF)
           response = child.before
-          debug_msg(debug_flag, f"ddr_cli_configure: response: {str(response)}")
+          ddr_debug_msg(debug_flag, f"ddr_cli_configure: response: {str(response)}")
 
         except Exception as e:
           child.close()
@@ -986,7 +986,7 @@ def ddr_cli_configure(device, access_type, command, return_response, timestamp,
       else:
         return None
     except Exception as e:
-      error_msg(f"ddr_cli_configure Exception: {str(e)}")
+      ddr_error_msg(f"ddr_cli_configure Exception: {str(e)}")
       raise
 
 def ddr_trigger_notify(device, triggers, debug_flag=False):
@@ -1016,7 +1016,7 @@ def ddr_trigger_notify(device, triggers, debug_flag=False):
         notify_conn.create_subscription(stream_name='snmpevents')
 
         timestamp =  datetime.now().strftime("%m-%d-%Y_%H:%M:%S.%f")
-        debug_msg(debug_flag, f"ddr_trigger_notify: Connected to notification stream from: {str(device[0])} at: {str(timestamp)}")
+        ddr_debug_msg(debug_flag, f"ddr_trigger_notify: Connected to notification stream from: {str(device[0])} at: {str(timestamp)}")
 #
 # block and wait until an RFC5277 NETCONF notification is received
 #
@@ -1024,7 +1024,7 @@ def ddr_trigger_notify(device, triggers, debug_flag=False):
         while not notification_trigger:
             notif = notify_conn.take_notification(block=True) # block on IO waiting for the NETCONF notification
             notify_xml = notif.notification_xml
-            debug_msg(debug_flag, f"ddr_trigger_notify: RFC5277 notification received: {str(notify_xml)}")
+            ddr_debug_msg(debug_flag, f"ddr_trigger_notify: RFC5277 notification received: {str(notify_xml)}")
 
 ######################################################################################
 # Test to see if the snmpevents notification included any of the strings that
@@ -1045,7 +1045,7 @@ def ddr_trigger_notify(device, triggers, debug_flag=False):
  
             if notification_trigger:
                 timestamp =  datetime.now().strftime("%m-%d-%Y_%H:%M:%S.%f")
-                debug_msg(debug_flag, f"ddr_trigger_notify: Triggering Notification Event Found:  {str(trigger)} at: {str(timestamp)}")
+                ddr_debug_msg(debug_flag, f"ddr_trigger_notify: Triggering Notification Event Found:  {str(trigger)} at: {str(timestamp)}")
                 break # If all strings in trigger are in notification notification is found so return
 #
 #    Loop until required notification is found
@@ -1054,7 +1054,7 @@ def ddr_trigger_notify(device, triggers, debug_flag=False):
         return notify_xml
     except Exception as e:
         notify_conn.close_session()
-        error_msg(f"ddr_trigger_notify Exception: {str(e)}")
+        ddr_error_msg(f"ddr_trigger_notify Exception: {str(e)}")
         raise
 
     notify_conn.close_session()
@@ -1110,7 +1110,7 @@ def ddr_decode_btrace_log(device, access_type, show_template, pcount, par1, par2
         try:
           response = cli.cli(command)
         except:
-          error_msg("run_decode_btrace_log cli access method not available")
+          ddr_error_msg("run_decode_btrace_log cli access method not available")
           raise
                 
       else:
@@ -1130,12 +1130,12 @@ def ddr_decode_btrace_log(device, access_type, show_template, pcount, par1, par2
 
         except Exception as e:
           child.close()
-          error_msg("run_decode_btrace_log SSH or timeout: {str(ssh_cmd)}")
+          ddr_error_msg("run_decode_btrace_log SSH or timeout: {str(ssh_cmd)}")
           raise
         child.close()
 
     except Exception as e:
-      error_msg("run_decode_btrace_log: Exception sending show command: {str(e)}")
+      ddr_error_msg("run_decode_btrace_log: Exception sending show command: {str(e)}")
       raise
     #
     # Search for content in log file
@@ -1150,7 +1150,7 @@ def ddr_decode_btrace_log(device, access_type, show_template, pcount, par1, par2
         if m:
           matched_lines.append(line)
     except Exception as e:
-      error_msg("run_decode_btrace_log regex: {str(match_string)} {str(e)}")
+      ddr_error_msg("run_decode_btrace_log regex: {str(match_string)} {str(e)}")
       raise
 
     #
@@ -1163,7 +1163,7 @@ def ddr_decode_btrace_log(device, access_type, show_template, pcount, par1, par2
           wfd.write(response)
           wfd.close()
       except Exception as e:
-        error_msg("run_decode_btrace_log: Exception saving btrace log: {str(e)}")
+        ddr_error_msg("run_decode_btrace_log: Exception saving btrace log: {str(e)}")
         raise
     return matched_lines
     
@@ -1252,21 +1252,21 @@ def ddr_show_parameter_all(device, access_type, genie_parser_name, show_template
         # If access-type is cli use the Python CLI package to run command
         #
           if str(access_type) == 'cli':
-            debug_msg(debug_flag, f" ddr_show_parameter_all: cli python command: {str(command)}")
+            ddr_debug_msg(debug_flag, f" ddr_show_parameter_all: cli python command: {str(command)}")
             response = cli.cli(command)
-            debug_msg(debug_flag, f" ddr_show_parameter_all: cli python response: {str(response)}")
+            ddr_debug_msg(debug_flag, f" ddr_show_parameter_all: cli python response: {str(response)}")
 
           else:
-            error_msg(f"ddr_show_parameter_all Exception: only cli device access option currently supported")
+            ddr_error_msg(f"ddr_show_parameter_all Exception: only cli device access option currently supported")
             raise
     #
     # parse the response to get the test leaf value
     #
           parser = genie_str_to_class(genie_parser_name)
           dictionary = parser.cli(output=response)
-          debug_msg(debug_flag, f"ddr_show_parameter_all: parser dictionary: {str(dictionary)}")
+          ddr_debug_msg(debug_flag, f"ddr_show_parameter_all: parser dictionary: {str(dictionary)}")
           return dictionary
 
         except Exception as e:
-          error_msg(f"ddr_show_parameter_all Exception: {str(e)}")
+          ddr_error_msg(f"ddr_show_parameter_all Exception: {str(e)}")
           raise
